@@ -4,7 +4,7 @@ Sage Intacct Python SDK
 from .apis import ApiBase, Contacts, Locations, Employees, Accounts, ExpenseTypes, Attachments, ExpenseReports,\
     Vendors, Bills, Projects, Departments, ChargeCardAccounts, ChargeCardTransactions, Customers, Items,\
     APPayments, Reimbursements, CheckingAccounts, SavingsAccounts, Tasks, ExpensePaymentTypes, Dimensions,\
-    DimensionValues, LocationEntities, ARInvoices, TaxDetails, GLDetail, Classes
+    DimensionValues, LocationEntities, ARInvoices, TaxDetails, GLDetail, Classes, JournalEntries
 
 
 class SageIntacctSDK:
@@ -60,6 +60,7 @@ class SageIntacctSDK:
         self.tax_details = TaxDetails()
         self.gl_detail = GLDetail()
         self.classes = Classes()
+        self.journal_entries = JournalEntries()
         self.update_sender_id()
         self.update_sender_password()
         self.update_session_id()
@@ -97,6 +98,7 @@ class SageIntacctSDK:
         self.tax_details.set_sender_id(self.__sender_id)
         self.gl_detail.set_sender_id(self.__sender_id)
         self.classes.set_sender_id(self.__sender_id)
+        self.journal_entries.set_sender_id(self.__sender_id)
 
     def update_sender_password(self):
         """
@@ -131,6 +133,7 @@ class SageIntacctSDK:
         self.tax_details.set_sender_password(self.__sender_password)
         self.gl_detail.set_sender_password(self.__sender_password)
         self.classes.set_sender_password(self.__sender_password)
+        self.journal_entries.set_sender_password(self.__sender_password)
 
     def update_session_id(self):
         """
@@ -167,3 +170,4 @@ class SageIntacctSDK:
         self.tax_details.set_session_id(self.__session_id)
         self.gl_detail.set_session_id(self.__session_id)
         self.classes.set_session_id(self.__session_id)
+        self.journal_entries.set_session_id(self.__session_id)
